pub struct ChangelogGenerator { /* private fields */ }Expand description
Generator for changelog files.
Implementations
Sourceimpl ChangelogGenerator
impl ChangelogGenerator
Sourcepub const fn new(config: ChangelogConfig) -> Self
pub const fn new(config: ChangelogConfig) -> Self
Create a new changelog generator with the given configuration.
Sourcepub fn default_config() -> Self
pub fn default_config() -> Self
Create a changelog generator with default configuration.
Sourcepub fn generate_entries(
&self,
changesets: &[Changeset],
package: &str,
version: &Version,
) -> Option<ChangelogEntry>
pub fn generate_entries( &self, changesets: &[Changeset], package: &str, version: &Version, ) -> Option<ChangelogEntry>
Generate changelog entries from changesets for a specific package.
Sourcepub fn generate_workspace_entry(
&self,
changesets: &[Changeset],
new_versions: &HashMap<String, Version>,
) -> Option<ChangelogEntry>
pub fn generate_workspace_entry( &self, changesets: &[Changeset], new_versions: &HashMap<String, Version>, ) -> Option<ChangelogEntry>
Generate a workspace-level changelog entry.
Sourcepub fn update_file(&self, path: &Path, entry: &ChangelogEntry) -> Result<()>
pub fn update_file(&self, path: &Path, entry: &ChangelogEntry) -> Result<()>
Update a changelog file with a new entry.
Errors
Returns an error if the file cannot be read or written.
Sourcepub fn get_changelog_path(&self, package_root: &Path) -> PathBuf
pub fn get_changelog_path(&self, package_root: &Path) -> PathBuf
Get the changelog file path for a package.