pub struct CommitAnalyzer<'a> { /* private fields */ }Expand description
Analyzes commits to determine which packages they affect.
This analyzer uses git diffs to map commits to packages based on which files were modified in each commit.
Implementations
Sourceimpl<'a> CommitAnalyzer<'a>
impl<'a> CommitAnalyzer<'a>
Sourcepub const fn new(
root: &'a Path,
package_paths: HashMap<String, PathBuf>,
) -> Self
pub const fn new( root: &'a Path, package_paths: HashMap<String, PathBuf>, ) -> Self
Create a new commit analyzer.
Arguments
root- The workspace root path.package_paths- Map of package names to their paths (relative to root).
Sourcepub fn analyze<'c>(
&self,
commits: &'c [ConventionalCommit],
) -> Result<HashMap<String, Vec<PackageAffect<'c>>>>
pub fn analyze<'c>( &self, commits: &'c [ConventionalCommit], ) -> Result<HashMap<String, Vec<PackageAffect<'c>>>>
Analyze commits and map them to affected packages.
Returns a map of package names to the commits that affected them, along with the specific files changed in that package.
Errors
Returns an error if git operations fail when analyzing commits.
Sourcepub fn calculate_bumps(
&self,
commits: &[ConventionalCommit],
) -> Result<HashMap<String, BumpType>>
pub fn calculate_bumps( &self, commits: &[ConventionalCommit], ) -> Result<HashMap<String, BumpType>>
Calculate the aggregate bump type per package from analyzed commits.
Returns a map of package names to their maximum bump type.
Errors
Returns an error if git operations fail when analyzing commits.